@@ -112,6 +112,17 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     # ,cover:不同头节点名删除×
     #########################################
 
+    platodb2csvDict={
+        "string":str,
+        "double":float,
+        "int":int
+    }
+    fillnaDict={
+        "string":"null",
+        "double":0.0,
+        "int":0
+    }
+
     if csvFolder[-1]=="/":
         csvFolder=csvFolder[:-1]
     
@@ -203,6 +214,12 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                         rawSchemaJson["vertex"][vertexI]["attr_type_map"][mkupColName]=attrTypeDict[mkupColName]
                         
                     nodeItemCInfoDf.drop(colItem,axis=1,inplace=True)
+            for colItem in nodeItemCInfoDf:
+                if colItem != "newMadeSysID":
+                    try:
+                        nodeItemCInfoDf[colItem]=nodeItemCInfoDf[colItem].astype(platodb2csvDict[attrTypeDict[colItem]])
+                    except ValueError:
+                        nodeItemCInfoDf[colItem]=nodeItemCInfoDf[colItem].fillna(fillnaDict[attrTypeDict[colItem]]).astype(platodb2csvDict[attrTypeDict[colItem]])
             csvDfItem=nodeItemCInfoDf
         elif vertexAttrProcess=="cover":
             pass
